File synchronization from remote instances
Provides unified file sync functionality for both action attachments and profile picture synchronization.
Structs
- Sync
Result - Result of a file sync operation
Functions
- get_
default_ sync_ max - Get the default sync max for a variant class
- get_
sync_ setting_ key - Get the sync setting key for a variant class (returns None for doc/raw - always sync)
- get_
sync_ source - Determine sync source based on action context
- is_
audience - Check if we are the audience (must sync ALL variants)
- sync_
file_ variants - Sync file variants from a remote instance