pub struct FilePreset {
pub name: String,
pub allowed_media_classes: Vec<VariantClass>,
pub image_variants: Vec<String>,
pub video_variants: Vec<String>,
pub audio_variants: Vec<String>,
pub extract_audio: bool,
pub generate_thumbnail: bool,
pub max_variant: Option<String>,
pub thumbnail_variant: Option<String>,
pub store_original: bool,
}Expand description
File processing preset configuration
Fields
name: StringPreset name (e.g., “default”, “podcast”, “archive”)
allowed_media_classes: Vec<VariantClass>Allowed media classes for upload (e.g., [Visual, Video, Audio])
image_variants: Vec<String>Image/visual variants to generate (e.g., [“vis.tn”, “vis.sd”, “vis.md”, “vis.hd”])
video_variants: Vec<String>Video variants to generate (e.g., [“vid.sd”, “vid.md”, “vid.hd”])
audio_variants: Vec<String>Audio variants to generate (e.g., [“aud.md”])
extract_audio: boolExtract audio track from video files
generate_thumbnail: boolGenerate thumbnail for video/audio/document files
max_variant: Option<String>Maximum variant to generate (caps generation at this level)
thumbnail_variant: Option<String>Variant to create synchronously for immediate thumbnail response (e.g., “vis.pf” or “vis.tn”)
store_original: boolStore original blob (file_variant record is always created, but blob storage is optional)