Module sync

Module sync 

File synchronization from remote instances

Provides unified file sync functionality for both action attachments and profile picture synchronization.

Structs

SyncResult
Result of a file sync operation

Functions

get_default_sync_max
Get the default sync max for a variant class
get_sync_setting_key
Get the sync setting key for a variant class (returns None for doc/raw - always sync)
get_sync_source
Determine sync source based on action context
is_audience
Check if we are the audience (must sync ALL variants)
sync_file_variants
Sync file variants from a remote instance